import sys
from dictionary_loader import load_dictionary_from_supabase
from audio_processing import process_audio

def initialize():
    success = load_dictionary_from_supabase()
    if not success:
        print("Warning: Dictionary loading failed. Proceeding with default dictionary.")

def process_audio_file(audio_file):
    try:
        raw_transcript, corrected_transcript = process_audio(audio_file)
        if raw_transcript and corrected_transcript:
            return corrected_transcript
        else:
            return None
    except Exception as e:
        print(f"Error processing audio: {str(e)}")
        return None

def main(audio_file_path):
    initialize()
    try:
        with open(audio_file_path, "rb") as audio_file:
            result = process_audio_file(audio_file)
        
        if result:
            print(result)
        else:
            print("Audio processing failed.")
    except FileNotFoundError:
        print(f"Error: The file '{audio_file_path}' was not found.")
    except Exception as e:
        print(f"An unexpected error occurred: {str(e)}")

if __name__ == "__main__":
    if len(sys.argv) != 2:
        print("Usage: python script_name.py <audio_file_path>")
        sys.exit(1)
    
    audio_file_path = sys.argv[1]
    main(audio_file_path)